<?php
declare(strict_types=1);

namespace Infomaker\Everyware\Support;

use Exception;
use Infomaker\Everyware\Support\Interfaces\Logger;

/**
 * NewRelicLog
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\Support
 * @since   Infomaker\Everyware\Support\NewRelicLog 1.0.0
 */
class NewRelicLog implements Logger
{

    /**
     * Send error to New Relic if enabled else to log
     *
     * @param string         $message
     * @param Exception|null $exception
     */
    public static function error($message, $exception = null): void
    {
        if (\extension_loaded('newrelic')) {
            newrelic_notice_error($message, $exception);
        } else {
            error_log($exception instanceof Exception ?
                sprintf('%s: %s', $message, $exception->getMessage()) : $message);
        }
    }
}
